# Copyright (c) 2012 Martin Garcia <newluxfero@gmail.com>
#
# This file is part of python-producteev, and is made available under
# MIT license. See LICENSE for the full details.

Zones = {'Europe': ['Dublin', 'Lisbon', 'London', 'Amsterdam', 'Andorra', 'Belgrade', 'Berlin', 'Brussels', 'Budapest', 'Copenhagen', 'Gibraltar', 'Luxembourg', 'Madrid', 'Malta', 'Monaco', 'Oslo', 'Paris', 'Prague', 'Rome', 'Stockholm', 'Tirane', 'Vaduz', 'Vienna', 'Warsaw', 'Zurich', 'Athens', 'Bucharest', 'Chisinau', 'Helsinki', 'Istanbul', 'Kaliningrad', 'Kiev', 'Minsk', 'Riga', 'Sofia', 'Tallinn', 'Vilnius', 'Moscow', 'Samara'], 'Asia': ['Amman', 'Beirut', 'Damascus', 'Gaza', 'Jerusalem', 'Nicosia', 'Aden', 'Baghdad', 'Bahrain', 'Kuwait', 'Qatar', 'Riyadh', 'Tehran', 'Baku', 'Dubai', 'Muscat', 'Tbilisi', 'Yerevan', 'Kabul', 'Aqtau', 'Aqtobe', 'Ashgabat', 'Dushanbe', 'Karachi', 'Tashkent', 'Yekaterinburg', 'Calcutta', 'Colombo', 'Katmandu', 'Almaty', 'Bishkek', 'Dhaka', 'Omsk', 'Thimphu', 'Rangoon', 'Bangkok', 'Hovd', 'Jakarta', 'Krasnoyarsk', 'Phnom_Penh', 'Saigon', 'Vientiane', 'Brunei', 'Choibalsan', 'Hong_Kong', 'Irkutsk', 'Kuala_Lumpur', 'Macau', 'Makassar', 'Manila', 'Shanghai', 'Singapore', 'Taipei', 'Ulaanbaatar', 'Dili', 'Jayapura', 'Pyongyang', 'Seoul', 'Tokyo', 'Yakutsk', 'Vladivostok', 'Kamchatka', 'Magadan'], 'Australia': ['Perth', 'Adelaide', 'Darwin', 'Brisbane', 'Hobart', 'Sydney'], 'Africa': ['Abidjan', 'Accra', 'Bamako', 'Banjul', 'Bissau', 'Casablanca', 'Conakry', 'Dakar', 'El_Aaiun', 'Freetown', 'Lome', 'Monrovia', 'Nouakchott', 'Ouagadougou', 'Sao_Tome', 'Algiers', 'Bangui', 'Brazzaville', 'Ceuta', 'Douala', 'Kinshasa', 'Lagos', 'Libreville', 'Luanda', 'Malabo', 'Ndjamena', 'Niamey', 'Porto-Novo', 'Tunis', 'Windhoek', 'Blantyre', 'Bujumbura', 'Cairo', 'Gaborone', 'Harare', 'Johannesburg', 'Kigali', 'Lubumbashi', 'Lusaka', 'Maputo', 'Maseru', 'Mbabane', 'Tripoli', 'Addis_Ababa', 'Asmara', 'Dar_es_Salaam', 'Djibouti', 'Kampala', 'Khartoum', 'Mogadishu', 'Nairobi'], 'US': ['Eastern'], 'Etc': ['GMT'], 'Antarctica': ['Palmer', 'Rothera', 'Syowa', 'Mawson', 'Vostok', 'Davis', 'Casey', 'DumontDUrville'], 'Indian': ['Antananarivo', 'Comoro', 'Mayotte', 'Mahe', 'Mauritius', 'Reunion', 'Kerguelen', 'Maldives', 'Chagos', 'Cocos', 'Christmas'], 'Atlantic': ['Bermuda', 'Stanley', 'South_Georgia', 'Azores', 'Cape_Verde', 'Canary', 'Faroe', 'Reykjavik', 'St_Helena'], 'Pacific': ['Apia', 'Midway', 'Niue', 'Pago_Pago', 'Fakaofo', 'Honolulu', 'Johnston', 'Rarotonga', 'Tahiti', 'Marquesas', 'Gambier', 'Pitcairn', 'Easter', 'Galapagos', 'Palau', 'Guam', 'Port_Moresby', 'Saipan', 'Truk', 'Efate', 'Guadalcanal', 'Kosrae', 'Noumea', 'Ponape', 'Norfolk', 'Auckland', 'Fiji', 'Funafuti', 'Kwajalein', 'Majuro', 'Nauru', 'Tarawa', 'Wake', 'Wallis', 'Enderbury', 'Tongatapu', 'Kiritimati'], 'America': ['Anchorage', 'Los_Angeles', 'Tijuana', 'Vancouver', 'Whitehorse', 'Dawson_Creek', 'Denver', 'Edmonton', 'Hermosillo', 'Mazatlan', 'Phoenix', 'Yellowknife', 'Belize', 'Chicago', 'Costa_Rica', 'El_Salvador', 'Guatemala', 'Managua', 'Mexico_City', 'Regina', 'Tegucigalpa', 'Winnipeg', 'Bogota', 'Cayman', 'Grand_Turk', 'Guayaquil', 'Havana', 'Iqaluit', 'Jamaica', 'Lima', 'Montreal', 'Nassau', 'New_York', 'Panama', 'Port-au-Prince', 'Toronto', 'Caracas', 'Anguilla', 'Antigua', 'Aruba', 'Asuncion', 'Barbados', 'Boa_Vista', 'Campo_Grande', 'Cuiaba', 'Curacao', 'Dominica', 'Grenada', 'Guadeloupe', 'Guyana', 'Halifax', 'La_Paz', 'Manaus', 'Martinique', 'Montserrat', 'Port_of_Spain', 'Porto_Velho', 'Puerto_Rico', 'Rio_Branco', 'Santiago', 'Santo_Domingo', 'St_Kitts', 'St_Lucia', 'St_Thomas', 'St_Vincent', 'Thule', 'Tortola', 'St_Johns', 'Araguaina', 'Argentina', 'Bahia', 'Belem', 'Cayenne', 'Fortaleza', 'Godthab', 'Maceio', 'Miquelon', 'Montevideo', 'Paramaribo', 'Recife', 'Sao_Paulo', 'Noronha', 'Scoresbysund', 'Danmarkshavn']}